@@ -1,5 +1,5 @@
 (function() {var implementors = {};
-implementors["sysctl"] = ["impl Fail for <a class=\"enum\" href=\"sysctl/enum.SysctlError.html\" title=\"enum sysctl::SysctlError\">SysctlError</a>",];
+implementors["sysctl"] = [{text:"impl Fail for <a class=\"enum\" href=\"sysctl/enum.SysctlError.html\" title=\"enum sysctl::SysctlError\">SysctlError</a>",synthetic:false,types:["sysctl::SysctlError"]},];
 
             if (window.register_implementors) {
                 window.register_implementors(implementors);
