@@ -1,23 +1,24 @@
+#![allow(dead_code)]
+#![allow(unused_imports)]
+
 extern crate libc;
 extern crate sysctl;
 
-#[cfg(not(target_os = "macos"))]
-use libc::c_int;
-#[cfg(not(target_os = "macos"))]
-use std::mem;
+// Import the trait
+use sysctl::Sysctl;
 
-// Copied from /usr/include/sys/time.h
+// Converted from definition in from /usr/include/sys/time.h
 #[derive(Debug)]
 #[repr(C)]
-#[cfg(not(target_os = "macos"))]
 struct ClockInfo {
-    hz: c_int,   /* clock frequency */
-    tick: c_int, /* micro-seconds per hz tick */
-    spare: c_int,
-    stathz: c_int, /* statistics clock frequency */
-    profhz: c_int, /* profiling clock frequency */
+    hz: libc::c_int,   /* clock frequency */
+    tick: libc::c_int, /* micro-seconds per hz tick */
+    spare: libc::c_int,
+    stathz: libc::c_int, /* statistics clock frequency */
+    profhz: libc::c_int, /* profiling clock frequency */
 }
-#[cfg(not(target_os = "macos"))]
+
+#[cfg(any(target_os = "freebsd", target_os = "macos"))]
 fn main() {
     let ctl = sysctl::Ctl::new("kern.clockrate").expect("could not get sysctl: kern.clockrate");
 
@@ -28,11 +29,11 @@ fn main() {
     println!("Description: {:?}", d);
 
     let val_enum = ctl.value().expect("could not get sysctl value");
-    println!("ClockInfo raw data: {:?}", val_enum);
+    println!("ClockInfo raw data (byte array): {:?}", val_enum);
 
     if let sysctl::CtlValue::Struct(val) = val_enum {
         // Make sure we got correct data size
-        assert_eq!(mem::size_of::<ClockInfo>(), val.len());
+        assert_eq!(std::mem::size_of::<ClockInfo>(), val.len());
         let val_ptr: *const u8 = val.as_ptr();
         let struct_ptr: *const ClockInfo = val_ptr as *const ClockInfo;
         let struct_ref: &ClockInfo = unsafe { &*struct_ptr };
@@ -40,5 +41,7 @@ fn main() {
     }
 }
 
-#[cfg(target_os = "macos")]
-fn main() {}
+#[cfg(not(any(target_os = "freebsd", target_os = "macos")))]
+fn main() {
+    println!("This operation is only supported on FreeBSD and macOS.");
+}
